@@ -35,8 +35,14 @@ class Citations:
         # Dict mapping citations keys to BibTex entries
         self._all_citations: dict[str, str] = dict()
 
-        self.read_citations()
-        self._reset()
+        # store citation error
+        self._citation_err_msg = None
+
+        try:
+            self.read_citations()
+            self._reset()
+        except Exception as e:  # pragma: no cover
+            self._citation_err_msg = e
 
     def _reset(self):
         """Reset citations to default only (only for testing purposes)"""
@@ -91,27 +97,27 @@ class Citations:
             - The citation key for an entry in `pybamm/CITATIONS.txt` or
             - One or more BibTex formatted citations
         """
-
-        # Check if citation is a known key
-        if key in self._all_citations:
-            self._papers_to_cite.add(key)
-            return
-
-        # Try to parse the citation using pybtex
-        try:
-            # Parse string as a bibtex citation, and check that a citation was found
-            bib_data = parse_string(key, bib_format="bibtex")
-            if not bib_data.entries:
-                raise PybtexError("no entries found")
-
-            # Add and register all citations
-            for key, entry in bib_data.entries.items():
-                self._add_citation(key, entry)
-                self.register(key)
+        if self._citation_err_msg is None:
+            # Check if citation is a known key
+            if key in self._all_citations:
+                self._papers_to_cite.add(key)
                 return
-        except PybtexError:
-            # Unable to parse / unknown key
-            raise KeyError(f"Not a bibtex citation or known citation: {key}")
+
+            # Try to parse the citation using pybtex
+            try:
+                # Parse string as a bibtex citation, and check that a citation was found
+                bib_data = parse_string(key, bib_format="bibtex")
+                if not bib_data.entries:
+                    raise PybtexError("no entries found")
+
+                # Add and register all citations
+                for key, entry in bib_data.entries.items():
+                    self._add_citation(key, entry)
+                    self.register(key)
+                    return
+            except PybtexError:
+                # Unable to parse / unknown key
+                raise KeyError(f"Not a bibtex citation or known citation: {key}")
 
     def print(self, filename=None, output_format="text"):
         """Print all citations that were used for running simulations.
@@ -143,7 +149,17 @@ class Citations:
 
 def print_citations(filename=None, output_format="text"):
     """See :meth:`Citations.print`"""
-    pybamm.citations.print(filename, output_format)
+    if citations._citation_err_msg is not None:
+        raise ImportError(
+            f"Citations could not be registered. If you are on Google Colab - "
+            "pybtex does not work with Google Colab due to a known bug - "
+            "https://bitbucket.org/pybtex-devs/pybtex/issues/148/. "
+            "Please manually cite all the references."
+            "\nError encountered -\n"
+            f"{citations._citation_err_msg}"
+        )
+    else:
+        pybamm.citations.print(filename, output_format)
 
 
 citations = Citations()
