@@ -144,36 +144,25 @@ def x_average(symbol):
         else:  # pragma: no cover
             # It should be impossible to get here
             raise NotImplementedError
-    # If symbol is a concatenation of Broadcasts, its average value is the
-    # thickness-weighted average of the symbols being broadcasted
-    elif isinstance(symbol, pybamm.Concatenation) and all(
-        isinstance(child, pybamm.Broadcast) for child in symbol.children
+    # If symbol is a concatenation, its average value is the
+    # thickness-weighted average of the average of its children
+    elif isinstance(symbol, pybamm.Concatenation) and not isinstance(
+        symbol, pybamm.ConcatenationVariable
     ):
         geo = pybamm.geometric_parameters
-        l_n = geo.n.l
-        l_s = geo.s.l
-        l_p = geo.p.l
-        if symbol.domain == ["negative electrode", "separator", "positive electrode"]:
-            a, b, c = [orp.orphans[0] for orp in symbol.orphans]
-            out = (l_n * a + l_s * b + l_p * c) / (l_n + l_s + l_p)
-        elif symbol.domain == ["separator", "positive electrode"]:
-            b, c = [orp.orphans[0] for orp in symbol.orphans]
-            out = (l_s * b + l_p * c) / (l_s + l_p)
-        # To respect domains we may need to broadcast the child back out
-        child = symbol.children[0]
-        # If symbol being returned doesn't have empty domain, return it
-        if out.domain != []:
-            return out
-        # Otherwise we may need to broadcast it
-        elif child.domains["secondary"] == []:
-            return out
-        else:
-            domain = child.domains["secondary"]
-            if child.domains["tertiary"] == []:
-                return pybamm.PrimaryBroadcast(out, domain)
-            else:
-                auxiliary_domains = {"secondary": child.domains["tertiary"]}
-                return pybamm.FullBroadcast(out, domain, auxiliary_domains)
+        ls = {
+            ("negative electrode",): geo.n.l,
+            ("separator",): geo.s.l,
+            ("positive electrode",): geo.p.l,
+            ("separator", "positive electrode"): geo.s.l + geo.p.l,
+        }
+        out = sum(
+            ls[tuple(orp.domain)] * x_average(orp) for orp in symbol.orphans
+        ) / sum(ls[tuple(orp.domain)] for orp in symbol.orphans)
+        return out
+    # Average of a sum is sum of averages
+    elif isinstance(symbol, (pybamm.Addition, pybamm.Subtraction)):
+        return _sum_of_averages(symbol, x_average)
     # Otherwise, use Integral to calculate average value
     else:
         return XAverage(symbol)
@@ -210,6 +199,9 @@ def z_average(symbol):
     # If symbol is a Broadcast, its average value is its child
     elif isinstance(symbol, pybamm.Broadcast):
         return symbol.reduce_one_dimension()
+    # Average of a sum is sum of averages
+    elif isinstance(symbol, (pybamm.Addition, pybamm.Subtraction)):
+        return _sum_of_averages(symbol, z_average)
     # Otherwise, define a ZAverage
     else:
         return ZAverage(symbol)
@@ -243,6 +235,9 @@ def yz_average(symbol):
     # If symbol is a Broadcast, its average value is its child
     elif isinstance(symbol, pybamm.Broadcast):
         return symbol.reduce_one_dimension()
+    # Average of a sum is sum of averages
+    elif isinstance(symbol, (pybamm.Addition, pybamm.Subtraction)):
+        return _sum_of_averages(symbol, yz_average)
     # Otherwise, define a YZAverage
     else:
         return YZAverage(symbol)
@@ -288,6 +283,9 @@ def r_average(symbol):
         and has_particle_domain
     ):
         return symbol.reduce_one_dimension()
+    # Average of a sum is sum of averages
+    elif isinstance(symbol, (pybamm.Addition, pybamm.Subtraction)):
+        return _sum_of_averages(symbol, r_average)
     else:
         return RAverage(symbol)
 
@@ -343,3 +341,10 @@ def size_average(symbol, f_a_dist=None):
             elif ["positive particle size"] in symbol.domains.values():
                 f_a_dist = geo.p.prim.f_a_dist(R)
         return SizeAverage(symbol, f_a_dist)
+
+
+def _sum_of_averages(symbol, average_function):
+    if isinstance(symbol, pybamm.Addition):
+        return average_function(symbol.left) + average_function(symbol.right)
+    elif isinstance(symbol, pybamm.Subtraction):
+        return average_function(symbol.left) - average_function(symbol.right)
