@@ -210,14 +210,9 @@ def find_symbols(symbol, constant_symbols, variable_symbols, output_jax=False):
                         children_vars[0], children_vars[1]
                     )
             elif scipy.sparse.issparse(dummy_eval_right):
-                if output_jax and is_scalar(dummy_eval_left):
-                    symbol_str = "{1}.scalar_multiply({0})".format(
-                        children_vars[0], children_vars[1]
-                    )
-                else:
-                    symbol_str = "{1}.multiply({0})".format(
-                        children_vars[0], children_vars[1]
-                    )
+                symbol_str = "{1}.multiply({0})".format(
+                    children_vars[0], children_vars[1]
+                )
             else:
                 symbol_str = "{0} * {1}".format(children_vars[0], children_vars[1])
         elif isinstance(symbol, pybamm.Division):
