@@ -11,27 +11,23 @@ class Scalar(pybamm.Symbol):
     """
     A node in the expression tree representing a scalar value.
 
-    **Extends:** :class:`Symbol`
-
     Parameters
     ----------
-
     value : numeric
         the value returned by the node when evaluated
     name : str, optional
-        the name of the node. Defaulted to ``str(value)``
-        if not provided
-    domain : iterable of str, optional
-        list of domains the parameter is valid over, defaults to empty list
+        the name of the node. Defaulted to ``str(value)`` if not provided
+
+    **Extends:** :class:`Symbol`
     """
 
-    def __init__(self, value, name=None, domain=[]):
+    def __init__(self, value, name=None):
         # set default name if not provided
         self.value = value
         if name is None:
             name = str(self.value)
 
-        super().__init__(name, domain=domain)
+        super().__init__(name)
 
     def __str__(self):
         return str(self.value)
@@ -48,10 +44,8 @@ class Scalar(pybamm.Symbol):
     def set_id(self):
         """See :meth:`pybamm.Symbol.set_id()`."""
         # We must include the value in the hash, since different scalars can be
-        # indistinguishable by class, name and domain alone
-        self._id = hash(
-            (self.__class__, self.name) + tuple(self.domain) + tuple(str(self._value))
-        )
+        # indistinguishable by class and name alone
+        self._id = hash((self.__class__, str(self.value)))
 
     def _base_evaluate(self, t=None, y=None, y_dot=None, inputs=None):
         """See :meth:`pybamm.Symbol._base_evaluate()`."""
@@ -63,7 +57,7 @@ class Scalar(pybamm.Symbol):
 
     def create_copy(self):
         """See :meth:`pybamm.Symbol.new_copy()`."""
-        return Scalar(self.value, self.name, self.domain)
+        return Scalar(self.value, self.name)
 
     def is_constant(self):
         """See :meth:`pybamm.Symbol.is_constant()`."""
