@@ -8,6 +8,7 @@ import numpy as np
 import sympy
 from anytree.exporter import DotExporter
 from scipy.sparse import csr_matrix, issparse
+from functools import lru_cache, cached_property
 
 import pybamm
 from pybamm.expression_tree.printing.print_name import prettify_print_name
@@ -200,7 +201,12 @@ class Symbol:
     """
 
     def __init__(
-        self, name, children=None, domain=None, auxiliary_domains=None, domains=None
+        self,
+        name,
+        children=None,
+        domain=None,
+        auxiliary_domains=None,
+        domains=None,
     ):
         super(Symbol, self).__init__()
         self.name = name
@@ -404,6 +410,14 @@ class Symbol:
             + tuple([(k, tuple(v)) for k, v in self.domains.items() if v != []])
         )
 
+    @property
+    def scale(self):
+        return self._scale
+
+    @property
+    def reference(self):
+        return self._reference
+
     def __eq__(self, other):
         try:
             return self._id == other._id
@@ -574,47 +588,19 @@ class Symbol:
 
     def __lt__(self, other):
         """return a :class:`NotEqualHeaviside` object, or a smooth approximation."""
-        k = pybamm.settings.heaviside_smoothing
-        # Return exact approximation if that is the setting or the outcome is a constant
-        # (i.e. no need for smoothing)
-        if k == "exact" or (is_constant(self) and is_constant(other)):
-            out = pybamm.NotEqualHeaviside(self, other)
-        else:
-            out = pybamm.sigmoid(self, other, k)
-        return pybamm.simplify_if_constant(out)
+        return pybamm.expression_tree.binary_operators._heaviside(self, other, False)
 
     def __le__(self, other):
         """return a :class:`EqualHeaviside` object, or a smooth approximation."""
-        k = pybamm.settings.heaviside_smoothing
-        # Return exact approximation if that is the setting or the outcome is a constant
-        # (i.e. no need for smoothing)
-        if k == "exact" or (is_constant(self) and is_constant(other)):
-            out = pybamm.EqualHeaviside(self, other)
-        else:
-            out = pybamm.sigmoid(self, other, k)
-        return pybamm.simplify_if_constant(out)
+        return pybamm.expression_tree.binary_operators._heaviside(self, other, True)
 
     def __gt__(self, other):
         """return a :class:`NotEqualHeaviside` object, or a smooth approximation."""
-        k = pybamm.settings.heaviside_smoothing
-        # Return exact approximation if that is the setting or the outcome is a constant
-        # (i.e. no need for smoothing)
-        if k == "exact" or (is_constant(self) and is_constant(other)):
-            out = pybamm.NotEqualHeaviside(other, self)
-        else:
-            out = pybamm.sigmoid(other, self, k)
-        return pybamm.simplify_if_constant(out)
+        return pybamm.expression_tree.binary_operators._heaviside(other, self, False)
 
     def __ge__(self, other):
         """return a :class:`EqualHeaviside` object, or a smooth approximation."""
-        k = pybamm.settings.heaviside_smoothing
-        # Return exact approximation if that is the setting or the outcome is a constant
-        # (i.e. no need for smoothing)
-        if k == "exact" or (is_constant(self) and is_constant(other)):
-            out = pybamm.EqualHeaviside(other, self)
-        else:
-            out = pybamm.sigmoid(other, self, k)
-        return pybamm.simplify_if_constant(out)
+        return pybamm.expression_tree.binary_operators._heaviside(other, self, True)
 
     def __neg__(self):
         """return a :class:`Negate` object."""
@@ -625,6 +611,9 @@ class Symbol:
             # Move negation inside the broadcast
             # Apply recursively
             return self._unary_new_copy(-self.orphans[0])
+        elif isinstance(self, pybamm.Subtraction):
+            # negation flips the subtraction
+            return self.right - self.left
         elif isinstance(self, pybamm.Concatenation) and all(
             child.is_constant() for child in self.children
         ):
@@ -640,7 +629,7 @@ class Symbol:
         elif isinstance(self, pybamm.Broadcast):
             # Move absolute value inside the broadcast
             # Apply recursively
-            abs_self_not_broad = pybamm.simplify_if_constant(abs(self.orphans[0]))
+            abs_self_not_broad = abs(self.orphans[0])
             return self._unary_new_copy(abs_self_not_broad)
         else:
             k = pybamm.settings.abs_smoothing
@@ -839,6 +828,7 @@ class Symbol:
     def evaluates_to_constant_number(self):
         return self.evaluates_to_number() and self.is_constant()
 
+    @lru_cache
     def evaluates_on_edges(self, dimension):
         """
         Returns True if a symbol evaluates on an edge, i.e. symbol contains a gradient
@@ -857,12 +847,9 @@ class Symbol:
             Whether the symbol evaluates on edges (in the finite volume discretisation
             sense)
         """
-        try:
-            return self._saved_evaluates_on_edges[dimension]
-        except KeyError:
-            eval_on_edges = self._evaluates_on_edges(dimension)
-            self._saved_evaluates_on_edges[dimension] = eval_on_edges
-            return eval_on_edges
+        eval_on_edges = self._evaluates_on_edges(dimension)
+        self._saved_evaluates_on_edges[dimension] = eval_on_edges
+        return eval_on_edges
 
     def _evaluates_on_edges(self, dimension):
         # Default behaviour: return False
@@ -906,48 +893,39 @@ class Symbol:
         obj._print_name = self.print_name
         return obj
 
-    @property
+    @cached_property
     def size(self):
         """
         Size of an object, found by evaluating it with appropriate t and y
         """
-        try:
-            return self._saved_size
-        except AttributeError:
-            self._saved_size = np.prod(self.shape)
-            return self._saved_size
+        return np.prod(self.shape)
 
-    @property
+    @cached_property
     def shape(self):
         """
         Shape of an object, found by evaluating it with appropriate t and y.
         """
+        # Default behaviour is to try to evaluate the object directly
+        # Try with some large y, to avoid having to unpack (slow)
         try:
-            return self._saved_shape
-        except AttributeError:
-            # Default behaviour is to try to evaluate the object directly
-            # Try with some large y, to avoid having to unpack (slow)
-            try:
-                y = np.nan * np.ones((1000, 1))
-                evaluated_self = self.evaluate(0, y, y, inputs="shape test")
-            # If that fails, fall back to calculating how big y should really be
-            except ValueError:
-                unpacker = pybamm.SymbolUnpacker(pybamm.StateVector)
-                state_vectors_in_node = unpacker.unpack_symbol(self)
-                min_y_size = max(
-                    max(len(x._evaluation_array) for x in state_vectors_in_node), 1
-                )
-                # Pick a y that won't cause RuntimeWarnings
-                y = np.nan * np.ones((min_y_size, 1))
-                evaluated_self = self.evaluate(0, y, y, inputs="shape test")
+            y = np.nan * np.ones((1000, 1))
+            evaluated_self = self.evaluate(0, y, y, inputs="shape test")
+        # If that fails, fall back to calculating how big y should really be
+        except ValueError:
+            unpacker = pybamm.SymbolUnpacker(pybamm.StateVector)
+            state_vectors_in_node = unpacker.unpack_symbol(self)
+            min_y_size = max(
+                max(len(x._evaluation_array) for x in state_vectors_in_node), 1
+            )
+            # Pick a y that won't cause RuntimeWarnings
+            y = np.nan * np.ones((min_y_size, 1))
+            evaluated_self = self.evaluate(0, y, y, inputs="shape test")
 
-            # Return shape of evaluated object
-            if isinstance(evaluated_self, numbers.Number):
-                self._saved_shape = ()
-            else:
-                self._saved_shape = evaluated_self.shape
-
-        return self._saved_shape
+        # Return shape of evaluated object
+        if isinstance(evaluated_self, numbers.Number):
+            return ()
+        else:
+            return evaluated_self.shape
 
     @property
     def size_for_testing(self):
