@@ -267,6 +267,11 @@ nca_ocp_Kim2011_data = pybamm.parameters.process_1D_data(
 )
 
 
+def nca_ocp_Kim2011(sto):
+    name, (x, y) = nca_ocp_Kim2011_data
+    return pybamm.Interpolant(x, y, sto, name=name, interpolator="linear")
+
+
 # Call dict via a function to avoid errors when editing in place
 def get_parameter_values():
     """
@@ -388,7 +393,7 @@ def get_parameter_values():
         "Positive electrode conductivity [S.m-1]": 10.0,
         "Maximum concentration in positive electrode [mol.m-3]": 49000.0,
         "Positive electrode diffusivity [m2.s-1]": nca_diffusivity_Kim2011,
-        "Positive electrode OCP [V]": nca_ocp_Kim2011_data,
+        "Positive electrode OCP [V]": nca_ocp_Kim2011,
         "Positive electrode porosity": 0.4,
         "Positive electrode active material volume fraction": 0.41,
         "Positive particle radius [m]": 1.633e-06,
