@@ -487,11 +487,16 @@ def electrolyte_conductivity_Nyman2008_arrhenius(c_e, T):
 
 # Load data in the appropriate format
 path, _ = os.path.split(os.path.abspath(__file__))
-graphite_LGM50_ocp_Chen2020 = pybamm.parameters.process_1D_data(
+graphite_LGM50_ocp_Chen2020_data = pybamm.parameters.process_1D_data(
     "graphite_LGM50_ocp_Chen2020.csv", path=path
 )
 
 
+def graphite_LGM50_ocp_Chen2020(sto):
+    name, (x, y) = graphite_LGM50_ocp_Chen2020_data
+    return pybamm.Interpolant(x, y, sto, name=name, interpolator="cubic")
+
+
 # Call dict via a function to avoid errors when editing in place
 def get_parameter_values():
     """
