@@ -4,6 +4,7 @@
 
 import pybamm
 import numbers
+from functools import cached_property
 
 
 class BatteryModelOptions(pybamm.FuzzyDict):
@@ -121,9 +122,10 @@ class BatteryModelOptions(pybamm.FuzzyDict):
 
                 - "none": :class:`pybamm.sei.NoSEI` (no SEI growth)
                 - "constant": :class:`pybamm.sei.Constant` (constant SEI thickness)
-                - "reaction limited", "solvent-diffusion limited",\
-                    "electron-migration limited", "interstitial-diffusion limited", \
-                    or "ec reaction limited": :class:`pybamm.sei.SEIGrowth`
+                - "reaction limited", "reaction limited (asymmetric)", \
+                    "solvent-diffusion limited", "electron-migration limited", \
+                    "interstitial-diffusion limited", "ec reaction limited" \
+                    or "ec reaction limited (asymmetric)": :class:`pybamm.sei.SEIGrowth`
             * "SEI film resistance" : str
                 Set the submodel for additional term in the overpotential due to SEI.
                 The default value is "none" if the "SEI" option is "none", and
@@ -255,10 +257,12 @@ class BatteryModelOptions(pybamm.FuzzyDict):
                 "none",
                 "constant",
                 "reaction limited",
+                "reaction limited (asymmetric)",
                 "solvent-diffusion limited",
                 "electron-migration limited",
                 "interstitial-diffusion limited",
                 "ec reaction limited",
+                "ec reaction limited (asymmetric)",
             ],
             "SEI film resistance": ["none", "distributed", "average"],
             "SEI on cracks": ["false", "true"],
@@ -597,19 +601,14 @@ class BatteryModelOptions(pybamm.FuzzyDict):
                 self._phases[domain] = phases
             return self._phases
 
-    @property
+    @cached_property
     def whole_cell_domains(self):
-        try:
-            return self._whole_cell_domains
-        except AttributeError:
-            if self["working electrode"] == "positive":
-                wcd = ["separator", "positive electrode"]
-            elif self["working electrode"] == "negative":
-                wcd = ["negative electrode", "separator"]
-            elif self["working electrode"] == "both":
-                wcd = ["negative electrode", "separator", "positive electrode"]
-            self._whole_cell_domains = wcd
-            return wcd
+        if self["working electrode"] == "positive":
+            return ["separator", "positive electrode"]
+        elif self["working electrode"] == "negative":
+            return ["negative electrode", "separator"]
+        elif self["working electrode"] == "both":
+            return ["negative electrode", "separator", "positive electrode"]
 
     @property
     def electrode_types(self):
@@ -843,7 +842,7 @@ class BaseBatteryModel(pybamm.BaseModel):
                 raise pybamm.OptionError("Lead-acid models cannot have lithium plating")
 
         if (
-            isinstance(self, (pybamm.lead_acid.LOQS, pybamm.lead_acid.Composite))
+            isinstance(self, pybamm.lead_acid.LOQS)
             and options["surface form"] == "false"
             and options["hydrolysis"] == "true"
         ):
