@@ -42,13 +42,6 @@ class BasePotentialPair(BaseModel):
         i_boundary_cc = pybamm.standard_variables.i_boundary_cc
 
         variables.update(self._get_standard_current_variables(i_cc, i_boundary_cc))
-        # Hack to get the leading-order current collector current density
-        # Note that this should be different from the actual (composite) current
-        # collector current density for 2+1D models, but not sure how to implement this
-        # using current structure of lithium-ion models
-        variables["Leading-order current collector current density"] = variables[
-            "Current collector current density"
-        ]
 
         return variables
 
