@@ -256,7 +256,7 @@ class BaseElectrolyteConductivity(pybamm.BaseSubModel):
             c_e_n = variables["Negative electrolyte concentration"]
             T_n = variables["Negative electrode temperature"]
             indef_integral_n = pybamm.IndefiniteIntegral(
-                param.chiT_over_c(c_e_n, T_n) * pybamm.grad(c_e_n),
+                param.chiRT_over_Fc(c_e_n, T_n) * pybamm.grad(c_e_n),
                 pybamm.standard_spatial_vars.x_n,
             )
 
@@ -270,11 +270,11 @@ class BaseElectrolyteConductivity(pybamm.BaseSubModel):
 
         # concentration overpotential
         indef_integral_s = pybamm.IndefiniteIntegral(
-            param.chiT_over_c(c_e_s, T_s) * pybamm.grad(c_e_s),
+            param.chiRT_over_Fc(c_e_s, T_s) * pybamm.grad(c_e_s),
             pybamm.standard_spatial_vars.x_s,
         )
         indef_integral_p = pybamm.IndefiniteIntegral(
-            param.chiT_over_c(c_e_p, T_p) * pybamm.grad(c_e_p),
+            param.chiRT_over_Fc(c_e_p, T_p) * pybamm.grad(c_e_p),
             pybamm.standard_spatial_vars.x_p,
         )
 
