@@ -12,5 +12,3 @@ from .inverse_kinetics.inverse_butler_volmer import (
     CurrentForInverseButlerVolmer,
     CurrentForInverseButlerVolmerLithiumMetal,
 )
-from .first_order_kinetics.first_order_kinetics import FirstOrderKinetics
-from .first_order_kinetics.inverse_first_order_kinetics import InverseFirstOrderKinetics
