@@ -37,32 +37,6 @@ class SymmetricButlerVolmer(BaseKinetics):
         prefactor = ne / (2 * (1 + self.param.Theta * T))
         return 2 * u * j0 * pybamm.sinh(prefactor * eta_r)
 
-    def _get_dj_dc(self, variables):
-        """See :meth:`pybamm.interface.kinetics.BaseKinetics._get_dj_dc`"""
-        (
-            c_e,
-            delta_phi,
-            j0,
-            ne,
-            ocp,
-            T,
-            u,
-        ) = self._get_interface_variables_for_first_order(variables)
-        eta_r = delta_phi - ocp
-        prefactor = ne / (2 * (1 + self.param.Theta * T))
-        return (2 * u * j0.diff(c_e) * pybamm.sinh(prefactor * eta_r)) - (
-            2 * u * j0 * prefactor * ocp.diff(c_e) * pybamm.cosh(prefactor * eta_r)
-        )
-
-    def _get_dj_ddeltaphi(self, variables):
-        """See :meth:`pybamm.interface.kinetics.BaseKinetics._get_dj_ddeltaphi`"""
-        _, delta_phi, j0, ne, ocp, T, u = self._get_interface_variables_for_first_order(
-            variables
-        )
-        eta_r = delta_phi - ocp
-        prefactor = ne / (2 * (1 + self.param.Theta * T))
-        return 2 * u * j0 * prefactor * pybamm.cosh(prefactor * eta_r)
-
 
 class AsymmetricButlerVolmer(BaseKinetics):
     """
