@@ -38,34 +38,6 @@ class ForwardTafel(BaseKinetics):
             u * j0 * pybamm.exp((ne * alpha / (2 * (1 + self.param.Theta * T))) * eta_r)
         )
 
-    def _get_dj_dc(self, variables):
-        """See :meth:`pybamm.interface.kinetics.BaseKinetics._get_dj_dc`"""
-        alpha = self.phase_param.alpha_bv
-        (
-            c_e,
-            delta_phi,
-            j0,
-            ne,
-            ocp,
-            T,
-            u,
-        ) = self._get_interface_variables_for_first_order(variables)
-        eta_r = delta_phi - ocp
-        return (2 * u * j0.diff(c_e)) * pybamm.exp(
-            (ne * alpha / (2 * (1 + self.param.Theta * T))) * eta_r
-        )
-
-    def _get_dj_ddeltaphi(self, variables):
-        """See :meth:`pybamm.interface.kinetics.BaseKinetics._get_dj_ddeltaphi`"""
-        alpha = self.phase_param.alpha_bv
-        _, delta_phi, j0, ne, ocp, T, u = self._get_interface_variables_for_first_order(
-            variables
-        )
-        eta_r = delta_phi - ocp
-        return (2 * u * j0 * (ne / (2 * (1 + self.param.Theta * T)))) * pybamm.exp(
-            (ne * alpha / (2 * (1 + self.param.Theta * T))) * eta_r
-        )
-
 
 # backwardtafel not used by any of the models
 # class BackwardTafel(BaseKinetics):
