@@ -422,7 +422,7 @@ class LeadAcidParameters(BaseParameters):
         kappa_scale = self.F**2 * self.D_e_typ * self.c_e_typ / (self.R * self.T_ref)
         return self.kappa_e_dimensional(c_e_dimensional, self.T_ref) / kappa_scale
 
-    def chiT_over_c(self, c_e, T):
+    def chiRT_over_Fc(self, c_e, T):
         """
         chi * (1 + Theta * T) / c,
         as it appears in the electrolyte potential equation
