@@ -1,5 +1,5 @@
 import warnings
-import pkg_resources
+import importlib_metadata
 import textwrap
 from collections.abc import Mapping
 
@@ -34,12 +34,12 @@ class ParameterSets(Mapping):
     """
 
     def __init__(self):
-        # Load Parameter Sets registered to `pybamm_parameter_set`
-        ps = dict()
-        for entry_point in pkg_resources.iter_entry_points("pybamm_parameter_set"):
-            ps[entry_point.name] = entry_point.load()
-
-        self.__all_parameter_sets = ps
+        # Dict of entry points for parameter sets, lazily load entry points as
+        self.__all_parameter_sets = dict()
+        for entry_point in importlib_metadata.entry_points(
+            group="pybamm_parameter_sets"
+        ):
+            self.__all_parameter_sets[entry_point.name] = entry_point
 
     def __new__(cls):
         """Ensure only one instance of ParameterSets exists"""
@@ -48,7 +48,18 @@ class ParameterSets(Mapping):
         return cls.instance
 
     def __getitem__(self, key) -> dict:
-        return self.__all_parameter_sets[key]()
+        return self.__load_entry_point__(key)()
+
+    def __load_entry_point__(self, key) -> callable:
+        """Check that ``key`` is a registered ``pybamm_parameter_sets``,
+        and return the entry point for the parameter set, loading it needed.
+        """
+        if key not in self.__all_parameter_sets:
+            raise KeyError(f"Unknown parameter set: {key}")
+        ps = self.__all_parameter_sets[key]
+        if isinstance(ps, importlib_metadata.EntryPoint):
+            ps = self.__all_parameter_sets[key] = ps.load()
+        return ps
 
     def __iter__(self):
         return self.__all_parameter_sets.__iter__()
@@ -58,7 +69,7 @@ class ParameterSets(Mapping):
 
     def get_docstring(self, key):
         """Return the docstring for the ``key`` parameter set"""
-        return textwrap.dedent(self.__all_parameter_sets[key].__doc__)
+        return textwrap.dedent(self.__load_entry_point__(key).__doc__)
 
     def __getattribute__(self, name):
         try:
@@ -67,16 +78,14 @@ class ParameterSets(Mapping):
             # For backwards compatibility, parameter sets that used to be defined in
             # this file now return the name as a string, which will load the same
             # parameter set as before when passed to `ParameterValues`
-            if name in self.__all_parameter_sets:
-                out = name
-            else:
-                raise error
-            warnings.warn(
-                f"Parameter sets should be called directly by their name ({name}), "
-                f"instead of via pybamm.parameter_sets (pybamm.parameter_sets.{name}).",
-                DeprecationWarning,
-            )
-            return out
+            if name in self:
+                msg = (
+                    "Parameter sets should be called directly by their name ({0}), "
+                    "instead of via pybamm.parameter_sets (pybamm.parameter_sets.{0})."
+                ).format(name)
+                warnings.warn(msg, DeprecationWarning)
+                return name
+            raise error
 
 
 #: Singleton Instance of :class:ParameterSets """
