@@ -365,7 +365,7 @@ class QuickPlot(object):
             if variable.domain[0] == "current collector":
                 domain = "current collector"
             else:
-                domain = variable.auxiliary_domains["secondary"][0]
+                domain = variable.domains["secondary"][0]
 
         if domain == "current collector":
             domain += " {}".format(spatial_var_name)
@@ -574,7 +574,7 @@ class QuickPlot(object):
                         var,
                         vmin=vmin,
                         vmax=vmax,
-                        shading='auto',
+                        shading="auto",
                     )
                 else:
                     self.plots[key][0][0] = ax.contourf(
@@ -727,7 +727,7 @@ class QuickPlot(object):
                         var,
                         vmin=vmin,
                         vmax=vmax,
-                        shading='auto',
+                        shading="auto",
                     )
                 else:
                     self.plots[key][0][0] = ax.contourf(
@@ -759,7 +759,7 @@ class QuickPlot(object):
             Name of the generated GIF file.
 
         """
-        import imageio
+        import imageio.v2 as imageio
         import matplotlib.pyplot as plt
 
         # time stamps at which the images/plots will be created
