@@ -32,7 +32,7 @@ class ScipySolver(pybamm.BaseSolver):
         method="BDF",
         rtol=1e-6,
         atol=1e-6,
-        extrap_tol=0,
+        extrap_tol=None,
         extra_options=None,
     ):
         super().__init__(
