@@ -9,6 +9,7 @@ import pickle
 import pybamm
 import pandas as pd
 from scipy.io import savemat
+from functools import cached_property
 
 
 class NumpyEncoder(json.JSONEncoder):
@@ -344,15 +345,9 @@ class Solution(object):
         """Model(s) used for solution"""
         return self._all_models
 
-    @property
+    @cached_property
     def all_inputs_casadi(self):
-        try:
-            return self._all_inputs_casadi
-        except AttributeError:
-            self._all_inputs_casadi = [
-                casadi.vertcat(*inp.values()) for inp in self.all_inputs
-            ]
-            return self._all_inputs_casadi
+        return [casadi.vertcat(*inp.values()) for inp in self.all_inputs]
 
     @property
     def t_event(self):
@@ -374,63 +369,55 @@ class Solution(object):
         """Updates the reason for termination"""
         self._termination = value
 
-    @property
+    @cached_property
     def first_state(self):
         """
         A Solution object that only contains the first state. This is faster to evaluate
         than the full solution when only the first state is needed (e.g. to initialize
         a model with the solution)
         """
-        try:
-            return self._first_state
-        except AttributeError:
-            new_sol = Solution(
-                self.all_ts[0][:1],
-                self.all_ys[0][:, :1],
-                self.all_models[:1],
-                self.all_inputs[:1],
-                None,
-                None,
-                "success",
-            )
-            new_sol._all_inputs_casadi = self.all_inputs_casadi[:1]
-            new_sol._sub_solutions = self.sub_solutions[:1]
+        new_sol = Solution(
+            self.all_ts[0][:1],
+            self.all_ys[0][:, :1],
+            self.all_models[:1],
+            self.all_inputs[:1],
+            None,
+            None,
+            "success",
+        )
+        new_sol._all_inputs_casadi = self.all_inputs_casadi[:1]
+        new_sol._sub_solutions = self.sub_solutions[:1]
 
-            new_sol.solve_time = 0
-            new_sol.integration_time = 0
-            new_sol.set_up_time = 0
+        new_sol.solve_time = 0
+        new_sol.integration_time = 0
+        new_sol.set_up_time = 0
 
-            self._first_state = new_sol
-            return self._first_state
+        return new_sol
 
-    @property
+    @cached_property
     def last_state(self):
         """
         A Solution object that only contains the final state. This is faster to evaluate
         than the full solution when only the final state is needed (e.g. to initialize
         a model with the solution)
         """
-        try:
-            return self._last_state
-        except AttributeError:
-            new_sol = Solution(
-                self.all_ts[-1][-1:],
-                self.all_ys[-1][:, -1:],
-                self.all_models[-1:],
-                self.all_inputs[-1:],
-                self.t_event,
-                self.y_event,
-                self.termination,
-            )
-            new_sol._all_inputs_casadi = self.all_inputs_casadi[-1:]
-            new_sol._sub_solutions = self.sub_solutions[-1:]
+        new_sol = Solution(
+            self.all_ts[-1][-1:],
+            self.all_ys[-1][:, -1:],
+            self.all_models[-1:],
+            self.all_inputs[-1:],
+            self.t_event,
+            self.y_event,
+            self.termination,
+        )
+        new_sol._all_inputs_casadi = self.all_inputs_casadi[-1:]
+        new_sol._sub_solutions = self.sub_solutions[-1:]
 
-            new_sol.solve_time = 0
-            new_sol.integration_time = 0
-            new_sol.set_up_time = 0
+        new_sol.solve_time = 0
+        new_sol.integration_time = 0
+        new_sol.set_up_time = 0
 
-            self._last_state = new_sol
-            return self._last_state
+        return new_sol
 
     @property
     def total_time(self):
